@@ -27,6 +27,13 @@ class InvalidSignature(NotificationValidationError):
     pass
 
 
+def ebay_timestamp_string(datetime_obj):
+    # convert python datetime obj to string representation used by eBay
+    # (truncate python's microseconds to eBay's milliseconds)
+    # eBay timestamps are UTC... the 'Z' timezone
+    return '%sZ' % datetime_obj.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3]
+
+
 class NotificationHandler(object):
     def __init__(self, wsdl_url=WSDL_URL, token=None, sandbox=False):
         es_kwargs = {
@@ -69,6 +76,7 @@ class NotificationHandler(object):
         http://developer.ebay.com/DevZone/XML/docs/WebHelp/wwhelp/wwhimpl/common/html/wwhelp.htm?context=eBay_XML_API&file=WorkingWithNotifications-Receiving_Platform_Notifications.html
         """
         
+        # get a float timestamp
         timestamp = time.mktime(message.Timestamp.timetuple())
         if not settings.DEBUG:
             # check timestamp is within 10 minutes of current time
@@ -78,7 +86,7 @@ class NotificationHandler(object):
         
         # make hash
         m = hashlib.md5()
-        m.update(str(timestamp))
+        m.update(ebay_timestamp_string(message.Timestamp))
         m.update(ebaysuds_config.get('keys', 'dev_id'))
         if self.client.sandbox:
             conf_section = 'sandbox_keys'
